# This is a set of default targets which a file can import to build a set of libraries in our system targeted at
# the various MinGW targets which we support. I won't document it too much, since I will probably be the only
# person to really ever use it. But we'll leave this here in case anyone ever wants to take a look at these things
# later on.

DEB_HOST_GNU_TYPE	?= $(shell dpkg-architecture -qDEB_HOST_GNU_TYPE)
DEB_BUILD_GNU_TYPE	?= $(shell dpkg-architecture -qDEB_BUILD_GNU_TYPE)

MINGW64_TARGET	= x86_64-w64-mingw32
MINGW32_TARGET	= i686-w64-mingw32

MINGW64_SYSROOT		= /usr/$(MINGW64_TARGET)/sys-root/
MINGW32_SYSROOT		= /usr/$(MINGW32_TARGET)/sys-root/

CFLAGS_BASE := -O2 -g -pipe -Wall -fno-omit-frame-pointer \
		--param=ssp-buffer-size=4 -D_GNU_SOURCE=1 \
                -D_POSIX_SOURCE=1

CFLAGS64			=-I$(MINGW64_SYSROOT)mingw/include $(CFLAGS_BASE)
				 
CXXFLAGS64			=$(CFLAGS64)

CFLAGS32			=-I$(MINGW32_SYSROOT)mingw/include $(CFLAGS_BASE)
CXXFLAGS32			=$(CFLAGS32)

LDFLAGS64			=-L$(MINGW64_SYSROOT)mingw/lib -Wl,--exclude-libs=libintl.a -Wl,--exclude-libs=libiconv.a
LDFLAGS32			=-L$(MINGW32_SYSROOT)mingw/lib -Wl,--exclude-libs=libintl.a -Wl,--exclude-libs=libiconv.a

MINGW64_ENVARS		= CFLAGS="$(CFLAGS64)" \
				CXXFLAGS="$(CXXFLAGS64)" \
				LDFLAGS="$(LDFLAGS64)" \
				CC=x86_64-w64-mingw32-gcc \
				CXX=x86_64-w64-mingw32-g++ \
				CPP="x86_64-w64-mingw32-gcc -E" \
				ADDR2LINE=x86_64-w64-mingw32-addr2line \
				AR=x86_64-w64-mingw32-gcc-ar \
				AS=x86_64-w64-mingw32-as \
				LD=x86_64-w64-mingw32-ld \
				DLLTOOL=x86_64-w64-mingw32-dlltool \
				DLLWRAP=x86_64-w64-mingw32-dllwrap \
				NM=x86_64-w64-mingw32-gcc-nm \
				OBJCOPY=x86_64-w64-mingw32-objcopy \
				OBJDUMP=x86_64-w64-mingw32-objdump \
				RANLIB=x86_64-w64-mingw32-gcc-ranlib \
				STRIP=x86_64-w64-mingw32-strip \
				RC=x86_64-w64-mingw32-windres \
				CXXCPP="x86_64-w64-mingw32-g++ -E" \
				PATH=$(MINGW64_SYSROOT)mingw/bin:$(PATH)

MINGW32_ENVARS		= CFLAGS="$(CFLAGS32)" \
				CXXFLAGS="$(CXXFLAGS32)" \
				LDFLAGS="$(LDFLAGS32)" \
				CC=i686-w64-mingw32-gcc \
				CXX=i686-w64-mingw32-g++ \
				CPP="i686-w64-mingw32-gcc -E" \
				ADDR2LINE=i686-w64-mingw32-addr2line \
				AR=i686-w64-mingw32-gcc-ar \
				AS=i686-w64-mingw32-as \
				LD=i686-w64-mingw32-ld \
				DLLTOOL=i686-w64-mingw32-dlltool \
				DLLWRAP=i686-w64-mingw32-dllwrap \
				NM=i686-w64-mingw32-gcc-nm \
				OBJCOPY=i686-w64-mingw32-objcopy \
				OBJDUMP=i686-w64-mingw32-objdump \
				RANLIB=i686-w64-mingw32-gcc-ranlib \
				STRIP=i686-w64-mingw32-strip \
				RC=i686-w64-mingw32-windres \
				CXXCPP="i686-w64-mingw32-g++ -E" \
				PATH=$(MINGW32_SYSROOT)mingw/bin:$(PATH)
				
MINGW64_CONFIGURE	= $(MINGW64_ENVARS) \
	$(CURDIR)/configure \
	--build=$(DEB_BUILD_GNU_TYPE) \
	--host=$(MINGW64_TARGET) \
	--prefix=$(MINGW64_SYSROOT)mingw \
	--bindir=$(MINGW64_SYSROOT)mingw/bin \
	--libdir=$(MINGW64_SYSROOT)mingw/lib \
	--cache-file=mingw64-config.cache

MINGW32_CONFIGURE	=  $(MINGW32_ENVARS) \
	$(CURDIR)/configure \
	--build=$(DEB_BUILD_GNU_TYPE) \
	--host=$(MINGW32_TARGET) \
	--prefix=$(MINGW32_SYSROOT)mingw \
	--bindir=$(MINGW32_SYSROOT)mingw/bin \
	--libdir=$(MINGW32_SYSROOT)mingw/lib \
	--cache-file=mingw32-config.cache

BUILD_ROOT	= debian/tmp
PREFIX		= /usr

CFLAGS		= -Wall -g
INSTALL		= install
INSTALL_FILE	= $(INSTALL) -p -o root -g root -m 644
INSTALL_PROGRAM	= $(INSTALL) -p -o root -g root -m 755
INSTALL_SCIPRT	= $(INSTALL) -p -o root -g root -m 755
INSTALL_DIR	= $(INSTALL) -p -d -o root -g root -m 755

ifneq (,$(filter noopt,$(DEB_BUILD_OPTIONS)))
	CFLAGS += -O0
else
	CFLAGS += -O2
endif

ifeq (,$(filter nostrip,$(DEB_BUILD_OPTIONS)))
	INSTALL_PROGRAM += -s
endif

ifneq (,$(filter parallel=%,$(DEB_BUILD_OPTIONS)))
	NUMJOBS = $(patsubst parallel=%,%,$(filter parallel=%,$(DEB_BUILD_OPTIONS)))
	MAKEFLAGS += -j$(NUMJOBS)
	#MAKEFLAGS = 
endif

build: build-stamp
build-stamp: configure-stamp
	
	# Build 64
	if [ -f debian/pre64_build.sh ]; then /bin/bash debian/pre64_build.sh; fi
	cd build-64 && $(MAKE) $(MAKEOPTS) all
	if [ -f debian/post64_build.sh ]; then /bin/bash debian/post64_build.sh; fi
	
	# Build 32
	if [ -f debian/pre32_build.sh ]; then /bin/bash debian/pre32_build.sh; fi
	cd build-32 && $(MAKE) $(MAKEOPTS) all
	if [ -f debian/post32_build.sh ]; then /bin/bash debian/post32_build.sh; fi
	
	touch build-stamp

clean:
	dh_testdir
	dh_testroot
	rm -rf build-stamp configure-stamp build-32 build-64 $(BUILD_ROOT) $(CLEAN_TARGETS)
	dh_clean

install: build
	dh_testdir
	dh_testroot
	dh_installdirs
	
	mkdir -p $(BUILD_ROOT)/64
	if [ -f debian/pre64_install.sh ]; then /bin/bash debian/pre64_install.sh; fi
	cd build-64 && $(MAKE) DESTDIR=$(CURDIR)/$(BUILD_ROOT)/64 install
	if [ -f debian/post64_install.sh ]; then /bin/bash debian/post64_install.sh; fi
	
	mkdir -p $(BUILD_ROOT)/32
	if [ -f debian/pre32_install.sh ]; then /bin/bash debian/pre32_install.sh; fi
	cd build-32 && $(MAKE) DESTDIR=$(CURDIR)/$(BUILD_ROOT)/32 install
	if [ -f debian/post32_install.sh ]; then /bin/bash debian/post32_install.sh; fi
		
binary-indep: build install
	dh_testdir -i
	dh_testroot -i
	dh_movefiles -i
	dh_installdocs -i
	dh_installexamples -i
	dh_install -i
	dh_link -i
	dh_fixperms -i
	dh_makeshlibs -i
	dh_installdeb -i
	dh_shlibdeps -i
	dh_installchangelogs $(CHANGELOG)
	dh_gencontrol -i
	dh_md5sums -i
	dh_builddeb -i

binary-arch: build install
	#dh_testdir -a
	#dh_testroot -a
	#dh_movefiles -a
	#dh_installdocs -a
	#dh_installexamples -a
	#dh_install -a
	#dh_link -a
	#dh_fixperms -a
	#dh_makeshlibs -a
	#dh_installdeb -a
	#dh_shlibdeps -a
	#dh_installchangelogs ChangeLog
	#dh_gencontrol -a
	#dh_md5sums -a
	#dh_builddeb -a

binary: binary-arch binary-indep
.PHONY: build clean binary-indep binary-arch binary install configure
